@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2007 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
+// Copyright (C) 2000-2008 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
 //  
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License in
@@ -31,34 +31,6 @@
 
 namespace trng {
 
-  namespace detail {
-
-    template<typename T>
-    inline T log2_floor(T x) {
-      T y(0);
-      while (x>0) {
-	x>>=1;
-	++y;
-      };
-      --y;
-      return y;
-    }
-    
-    template<typename T>
-    inline T log2_ceil(T x) {
-      T y(log2_floor(x));
-      if ((T(1)<<y)<x)
-        ++y;
-      return y;
-    }
-    
-    template<typename T>
-    inline T pow2(T x) {
-      return T(1) << x;
-    }
-    
-  }
-
   // non-uniform random number generator class
   class discrete_dist {
   public:
@@ -68,39 +40,39 @@ namespace trng {
     class param_type {
     private:
       typedef std::vector<double>::size_type size_type;
-      std::vector<double> P_;
+      std::vector<double> P;
       size_type N, offset, layers;
       
     public:
       template<typename iter>
       param_type(iter first, iter last) :
-	P_(first, last) {
-	N=P_.size();
-	layers=detail::log2_ceil(N);
-	offset=detail::pow2(layers)-1;
-	P_.resize(N+offset);
-	std::copy_backward(P_.begin(), P_.begin()+N, P_.end());
-	std::fill(P_.begin(), P_.begin()+N, 0);
+	P(first, last) {
+	N=P.size();
+	layers=math::log2_ceil(N);
+	offset=math::pow2(layers)-1;
+	P.resize(N+offset);
+	std::copy_backward(P.begin(), P.begin()+N, P.end());
+	std::fill(P.begin(), P.begin()+N, 0);
 	update_all_layers();
       }
       explicit param_type(int n) :
-	P_(n, 1.0) {
-	N=P_.size();
-	layers=detail::log2_ceil(N);
-	offset=detail::pow2(layers)-1;
-	P_.resize(N+offset);
-	std::copy_backward(P_.begin(), P_.begin()+N, P_.end());
-	std::fill(P_.begin(), P_.begin()+N, 0);
+	P(n, 1.0) {
+	N=P.size();
+	layers=math::log2_ceil(N);
+	offset=math::pow2(layers)-1;
+	P.resize(N+offset);
+	std::copy_backward(P.begin(), P.begin()+N, P.end());
+	std::fill(P.begin(), P.begin()+N, 0);
 	update_all_layers();
       }
     private:
       void update_layer(size_type layer, size_type n) {
-	size_type first=detail::pow2(layer)-1, last=first+n;
+	size_type first=math::pow2(layer)-1, last=first+n;
 	for (size_type i=first; i<last; ++i, ++i) 
 	  if (i+1<last)
-	    P_[(i-1)/2]=P_[i]+P_[i+1];
+	    P[(i-1)/2]=P[i]+P[i+1];
 	  else
-	    P_[(i-1)/2]=P_[i];
+	    P[(i-1)/2]=P[i];
       }
       void update_all_layers() {
 	size_type layer=layers;
@@ -109,7 +81,7 @@ namespace trng {
 	  --layer;
 	}
 	while (layer>0) {
-	  update_layer(layer, detail::pow2(layer));
+	  update_layer(layer, math::pow2(layer));
 	  --layer;
 	}
       }
@@ -143,13 +115,13 @@ namespace trng {
     // random numbers
     template<typename R>
     int operator()(R &r) {
-      double u=utility::uniformco(r)*P.P_[0];
+      double u=utility::uniformco(r)*P.P[0];
       int x=0;
       while (x<P.offset) {
-	if (u<P.P_[2*x+1]) {
+	if (u<P.P[2*x+1]) {
 	  x=2*x+1;
 	} else {
-	  u-=P.P_[2*x+1];
+	  u-=P.P[2*x+1];
 	  x=2*x+2;
 	}
       }
@@ -167,24 +139,24 @@ namespace trng {
     void param(const param_type &P_new) { P=P_new; }
     void param(int x, double p) {
       x+=P.offset;
-      P.P_[x]=p;
+      P.P[x]=p;
       if (x>0) {
 	do {
 	  x=(x-1)/2;
-	  P.P_[x]=P.P_[2*x+1]+P.P_[2*x+2];
+	  P.P[x]=P.P[2*x+1]+P.P[2*x+2];
 	} while (x>0);
       }
     }
     // probability density function  
     double pdf(int x) const {
-      return (x<0 || x>=static_cast<int>(P.N)) ? 0.0 : P.P_[x+P.offset]/P.P_[0];
+      return (x<0 || x>=static_cast<int>(P.N)) ? 0.0 : P.P[x+P.offset]/P.P[0];
     }
     // cumulative density function 
     double cdf(int x) const {
       if (x<0)
 	return 0.0;
       if (x<static_cast<int>(P.N))
-	return std::accumulate(&P.P_[P.offset], &P.P_[x+P.offset+1], 0.0)/P.P_[0];
+	return std::accumulate(&P.P[P.offset], &P.P[x+P.offset+1], 0.0)/P.P[0];
       return 1.0;
     }
   };
@@ -194,7 +166,7 @@ namespace trng {
   // EqualityComparable concept
   inline bool operator==(const discrete_dist::param_type &p1, 
 			 const discrete_dist::param_type &p2) {
-    return p1.P_==p2.P_;
+    return p1.P==p2.P;
   }
   inline bool operator!=(const discrete_dist::param_type &p1, 
 			 const discrete_dist::param_type &p2) {
@@ -210,9 +182,9 @@ namespace trng {
     out.flags(std::ios_base::dec | std::ios_base::fixed |
 	      std::ios_base::left);
     out << '(' << P.N << ' ';
-    for (std::vector<double>::size_type i=P.offset; i<P.P_.size(); ++i) {
-      out << std::setprecision(17) << P.P_[i];
-      if (i+1<P.P_.size())
+    for (std::vector<double>::size_type i=P.offset; i<P.P.size(); ++i) {
+      out << std::setprecision(17) << P.P[i];
+      if (i+1<P.P.size())
 	out << ' ';
     }
     out	<< ')';
