@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2007 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
+// Copyright (C) 2000-2008 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
 //  
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License in
@@ -37,8 +37,8 @@ namespace trng {
     // Uniform random number generator concept
     typedef unsigned long long result_type;
     result_type operator()() const;  
-    static const result_type min;
-    static const result_type max;
+    static const result_type min=0;
+    static const result_type max=18446744073709551615ull;
 
     // Parameter and status classes
     class parameter_type;
@@ -209,16 +209,6 @@ namespace trng {
     // Other useful methods
     static const char * name();
     long operator()(long) const;
-//     bool boolean() const;
-//     bool boolean(double) const;
-//     double uniformco() const;
-//     double uniformco(double, double) const;
-//     double uniformoc() const;
-//     double uniformoc(double, double) const;
-//     double uniformoo() const;
-//     double uniformoo(double, double) const;
-//     double uniformcc() const;
-//     double uniformcc(double, double) const;
 
   private:
     parameter_type P;
@@ -247,56 +237,6 @@ namespace trng {
     return static_cast<long>(utility::uniformco(*this)*x);
   }
 
-//   inline bool lcg64::boolean() const {
-//     step();
-//     return S.r<9223372036854775808ull;
-//   }
-  
-//   inline bool lcg64::boolean(double p) const {
-//     step();
-//     return S.r<18446744073709551616.0*p;
-//   }
-  
-//   inline double lcg64::uniformco() const {
-//     step();
-//     double t(S.r/18446744073709551616.0);
-//     return t<1.0 ? t : 1.0-math::numeric_limits<double>::epsilon();
-//   }
-  
-//   inline double lcg64::uniformco(double a, double b) const {
-//     return uniformco()*(b-a)+a;
-//     }
-  
-//   inline double lcg64::uniformoc() const {
-//     step();
-//     double t(S.r/18446744073709551616.0);
-//     return  t>0.0 ? t : math::numeric_limits<double>::epsilon();
-//     }
-  
-//   inline double lcg64::uniformoc(double a, double b) const {
-//     return uniformoc()*(b-a)+a;
-//   }
-  
-//   inline double lcg64::uniformoo() const {
-//     step();
-//     double t(S.r/18446744073709551616.0+
-// 	     math::numeric_limits<double>::epsilon());
-//     return t<1.0 ? t : 1.0-math::numeric_limits<double>::epsilon();
-//   }
-  
-//   inline double lcg64::uniformoo(double a, double b) const {
-//     return uniformoo()*(b-a)+a;
-//   }
-  
-//   inline double lcg64::uniformcc() const {
-//     step();
-//     return S.r/18446744073709551615.0;
-//   }
-  
-//   inline double lcg64::uniformcc(double a, double b) const {
-//     return uniformcc()*(b-a)+a;
-//   }
-
 }
 
 #endif
