@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2007 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
+// Copyright (C) 2000-2008 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
 //  
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License in
@@ -30,15 +30,14 @@ namespace trng {
   
   class mrg2 {
   public:
-  
     // Uniform random number generator concept
     typedef long result_type;
     result_type operator()() const;
   private:
-    static const result_type modulus;
+    static const result_type modulus=2147483647l;
   public:
-    static const result_type min;
-    static const result_type max;
+    static const result_type min=0l;
+    static const result_type max=2147483646l;
 
     // Parameter and status classes
     class parameter_type;
@@ -208,16 +207,6 @@ namespace trng {
     // Other useful methods
     static const char * name();
     long operator()(long) const;
-//     bool boolean() const;
-//     bool boolean(double) const;
-//     double uniformco() const;
-//     double uniformco(double, double) const;
-//     double uniformoc() const;
-//     double uniformoc(double, double) const;
-//     double uniformoo() const;
-//     double uniformoo(double, double) const;
-//     double uniformcc() const;
-//     double uniformcc(double, double) const;
 
   private:
     parameter_type P;
@@ -252,52 +241,6 @@ namespace trng {
     return static_cast<long>(utility::uniformco(*this)*x);
   }
 
-//   inline bool mrg2::boolean() const {
-//     step();
-//     return S.r1<=modulus/2;
-//   }
-
-//   inline bool mrg2::boolean(double p) const {
-//     step();
-//     return S.r1<modulus*p;
-//   }
-  
-//   inline double mrg2::uniformco() const {
-//     step();
-//     return static_cast<double>(S.r1)/static_cast<double>(modulus);
-//   }
-
-//   inline double mrg2::uniformco(double a, double b) const {
-//     return uniformco()*(b-a)+a;
-//   }
-  
-//   inline double mrg2::uniformoc() const {
-//     step();
-//     return (static_cast<double>(S.r1)+1.0)/static_cast<double>(modulus);
-//   }
-
-//   inline double mrg2::uniformoc(double a, double b) const {
-//     return uniformoc()*(b-a)+a;
-//   }
-  
-//   inline double mrg2::uniformoo() const {
-//     step();
-//     return (static_cast<double>(S.r1)+1.0)/(static_cast<double>(modulus)+1.0);
-//   }
-
-//   inline double mrg2::uniformoo(double a, double b) const {
-//     return uniformoo()*(b-a)+a;
-//   }
-
-//   inline double mrg2::uniformcc() const {
-//     step();
-//     return static_cast<double>(S.r1)/(static_cast<double>(modulus)-1.0);
-//   }
-  
-//   inline double mrg2::uniformcc(double a, double b) const {
-//     return uniformcc()*(b-a)+a;
-//   }
-    
 }
-  
+
 #endif
