@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2007 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
+// Copyright (C) 2000-2008 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
 //  
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License in
@@ -20,10 +20,7 @@
 namespace trng {
   
   // Uniform random number generator concept
-  const mrg3::result_type mrg3::modulus=2147483647l;
-  const mrg3::result_type mrg3::min=0l;
-  const mrg3::result_type mrg3::max=2147483646l;
-
+  
   // Parameter and status classes
 
   // EqualityComparable concept
