@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2007 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
+// Copyright (C) 2000-2008 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
 //  
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License in
@@ -35,10 +35,10 @@ namespace trng {
     typedef long result_type;
     result_type operator()() const;
   private:
-    static const result_type modulus;
+    static const result_type modulus=2147461007l;  // 2^31 - 22641
   public:
-    static const result_type min;
-    static const result_type max;
+    static const result_type min=0l;
+    static const result_type max=2147461006l;
 
     // Parameter and status classes
     class parameter_type;
@@ -227,16 +227,6 @@ namespace trng {
     // Other useful methods
     static const char * name();
     long operator()(long) const;
-//     bool boolean() const;
-//     bool boolean(double) const;
-//     double uniformco() const;
-//     double uniformco(double, double) const;
-//     double uniformoc() const;
-//     double uniformoc(double, double) const;
-//     double uniformoo() const;
-//     double uniformoo(double, double) const;
-//     double uniformcc() const;
-//     double uniformcc(double, double) const;
 
   private:
     parameter_type P;
@@ -277,53 +267,7 @@ namespace trng {
   inline long mrg5s::operator()(long x) const {
     return static_cast<long>(utility::uniformco(*this)*x);
   }
-
-//   inline bool mrg5s::boolean() const {
-//     step();
-//     return S.r1<=modulus/2;
-//   }
-
-//   inline bool mrg5s::boolean(double p) const {
-//     step();
-//     return S.r1<modulus*p;
-//   }
   
-//   inline double mrg5s::uniformco() const {
-//     step();
-//     return static_cast<double>(S.r1)/static_cast<double>(modulus);
-//   }
-
-//   inline double mrg5s::uniformco(double a, double b) const {
-//     return uniformco()*(b-a)+a;
-//   }
-  
-//   inline double mrg5s::uniformoc() const {
-//     step();
-//     return (static_cast<double>(S.r1)+1.0)/static_cast<double>(modulus);
-//   }
-
-//   inline double mrg5s::uniformoc(double a, double b) const {
-//     return uniformoc()*(b-a)+a;
-//   }
-  
-//   inline double mrg5s::uniformoo() const {
-//     step();
-//     return (static_cast<double>(S.r1)+1.0)/(static_cast<double>(modulus)+1.0);
-//   }
-
-//   inline double mrg5s::uniformoo(double a, double b) const {
-//     return uniformoo()*(b-a)+a;
-//   }
-
-//   inline double mrg5s::uniformcc() const {
-//     step();
-//     return static_cast<double>(S.r1)/(static_cast<double>(modulus)-1.0);
-//   }
-
-//   inline double mrg5s::uniformcc(double a, double b) const {
-//     return uniformcc()*(b-a)+a;
-//   }
-    
 }
   
 #endif
