@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2007 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
+// Copyright (C) 2000-2008 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
 //  
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License in
@@ -20,9 +20,6 @@
 namespace trng {
 
   // Uniform random number generator concept
-  const yarn3s::result_type yarn3s::modulus=2147462579l;  // 2^31-21069
-  const yarn3s::result_type yarn3s::min=0l;
-  const yarn3s::result_type yarn3s::max=2147462578l;
 
   // Parameter and status classes
 
